### R code from vignette source 'mhurdle.rnw'

###################################################
### code chunk number 1: mhurdle.rnw:95-96
###################################################
options(prompt= "R> ", useFancyQuotes = FALSE)


###################################################
### code chunk number 2: mhurdle.rnw:1556-1558
###################################################
library("Formula")
f <- Formula(y ~ x11 + x12  | x21 + x22 | x31 + x32)


###################################################
### code chunk number 3: mhurdle.rnw:1667-1668
###################################################
library("mhurdle")


###################################################
### code chunk number 4: mhurdle.rnw:1696-1700
###################################################
data("Comics", package = "mhurdle")
head(Comics, 3)
mean(Comics$comics == 0)
max(Comics$comics)


###################################################
### code chunk number 5: mhurdle.rnw:1766-1773
###################################################
Comics$incu <- with(Comics, income / cu)
Comics$incum <- with(Comics, incu / mean(incu))


model3 <- mhurdle(comics ~ 0 | log(incum) + I(log(incum)^2) +
                  I(log(incum)^3) + age  + gender + educ +
                  size| 0, data = Comics, dist = "n", method = 'bfgs')


###################################################
### code chunk number 6: mhurdle.rnw:1786-1789
###################################################
model5d <- mhurdle(comics ~ gender + educ + age |  log(incum) +
                   I(log(incum)^2) + I(log(incum)^3) + size | 0,
                   data = Comics, corr = "h1", dist = "n", method = 'bfgs')


###################################################
### code chunk number 7: mhurdle.rnw:1796-1797
###################################################
model5i <- update(model5d, corr = NULL)


###################################################
### code chunk number 8: mhurdle.rnw:1806-1807
###################################################
model2d <- update(model5d, dist = "l")


###################################################
### code chunk number 9: mhurdle.rnw:1812-1813
###################################################
model2i <- update(model2d, corr = NULL)


###################################################
### code chunk number 10: mhurdle.rnw:1820-1823
###################################################
model8d1 <- mhurdle(comics ~ gender + educ  |  log(incum) +
                    I(log(incum)^2) + I(log(incum)^3) + size | age,
                    data = Comics, corr = "h1", dist = "n", method = 'bfgs')


###################################################
### code chunk number 11: mhurdle.rnw:1832-1833
###################################################
summary(model8d1)


###################################################
### code chunk number 12: mhurdle.rnw:1849-1854
###################################################
coef(model8d1, "h2")
coef(model5d, "h1")
coef(model5d, "sigma")
coef(summary(model8d1), "h3")
vcov(model8d1, "h3")


###################################################
### code chunk number 13: mhurdle.rnw:1861-1863
###################################################
logLik(model5d)
logLik(model5d, naive = TRUE)


###################################################
### code chunk number 14: mhurdle.rnw:1872-1873
###################################################
head(fitted(model5d))


###################################################
### code chunk number 15: mhurdle.rnw:1880-1888
###################################################
predict(model5d,
        newdata = data.frame(
          comics = c(0, 1, 2),
          gender = c("female", "female", "male"),
          age = c(20, 18, 32),
          educ = c(10, 20, 5),
          incum = c(4, 8, 2),
          size = c(2, 1, 3)))


###################################################
### code chunk number 16: mhurdle.rnw:1908-1909
###################################################
rsq(model5d, type = "coefdet")


###################################################
### code chunk number 17: mhurdle.rnw:1921-1922
###################################################
rsq(model5d, type = "lratio", adj = TRUE)


###################################################
### code chunk number 18: mhurdle.rnw:1931-1932
###################################################
vuongtest(model5d, model8d1)


###################################################
### code chunk number 19: mhurdle.rnw:1959-1961
###################################################
vuongtest(model2d, model2i, type = 'nested', hyp = TRUE)
vuongtest(model2d, model2i, type = 'nested', hyp = FALSE)


###################################################
### code chunk number 20: mhurdle.rnw:1975-1976
###################################################
coef(summary(model2d), "rho")


###################################################
### code chunk number 21: mhurdle.rnw:1988-1991
###################################################
model3bis <- mhurdle(comics ~ 0 | log(incum) + I(log(incum)^2) +
                     I(log(incum)^3)  + gender + educ + age +
                     empl+area| 0, data = Comics, dist = "n", method = 'bfgs')


###################################################
### code chunk number 22: mhurdle.rnw:1998-1999
###################################################
vuongtest(model3, model3bis, type="overlapping")


###################################################
### code chunk number 23: mhurdle.rnw:2005-2006
###################################################
vuongtest(model3, model3bis, type="non-nested")


###################################################
### code chunk number 24: mhurdle.rnw:2016-2017
###################################################
vuongtest(model3bis, model3, type="overlapping", hyp=TRUE)


